@@ -19,13 +19,31 @@ DESCRIPTION
 
     This program allows you to see detailed information about a git repository.
 
-OPTIONS
-    -r, --suggest-reviewers
-        show the best people to contact to review code
+GENERATE OPTIONS
     -T, --detailed-git-stats
         give a detailed list of git stats
     -R, --git-stats-by-branch
         see detailed list of git stats by branch
+    -c, --changelogs
+        see changelogs
+    -L, --changelogs-by-author
+        see changelogs by author
+    -S, --my-daily-stats
+        see your current daily stats
+    -V, --csv-output-by-branch
+        output daily stats by branch in CSV format
+    -j, --json-output
+        save git log as a JSON formatted file to a specified area
+
+LIST OPTIONS
+    -b, --branch-tree
+        show an ASCII graph of the git repo branch history
+    -D, --branches-by-date
+        show branches by date
+    -C, --contributors
+        see a list of everyone who contributed to the repo
+    -a, --commits-per-author
+        displays a list of commits per author
     -d, --commits-per-day
         displays a list of commits per day
     -m, --commits-by-month
@@ -36,22 +54,14 @@ OPTIONS
         displays a list of commits per hour
     -A, --commits-by-author-by-hour
         displays a list of commits per hour by author
-    -a, --commits-per-author
-        displays a list of commits per author
-    -S, --my-daily-stats
-        see your current daily stats
-    -C, --contributors
-        see a list of everyone who contributed to the repo
-    -b, --branch-tree
-        show an ASCII graph of the git repo branch history
-    -D, --branches-by-date
-        show branches by date
-    -c, --changelogs
-        see changelogs
-    -L, --changelogs-by-author
-        see changelogs by author
-    -j, --json-output
-        save git log as a JSON formatted file to a specified area
+    -z, --commits-by-timezone
+        displays a list of commits per timezone
+    -Z, --commits-by-author-by-timezone
+        displays a list of commits per timezone by author
+
+SUGGEST OPTIONS
+    -r, --suggest-reviewers
+        show the best people to contact to review code
     -h, -?, --help
         display this help text in the terminal
 
@@ -69,7 +79,9 @@ ADDITIONAL USAGE
     You can also set _GIT_MERGE_VIEW to only show merge commits
         ex: export _GIT_MERGE_VIEW=exclusive
     You can set _MENU_THEME to display the legacy color scheme
-        ex: export _MENU_THEME=legacy"
+        ex: export _MENU_THEME=legacy
+    You can set _GIT_BRANCH to set the branch of the stats
+        ex: export _GIT_BRANCH=master"
 
 assert_raises "$src fail" 1
 
